@@ -11,7 +11,7 @@ def exists(funcname, modname=None):
     try:
         testfunc = eval(funcstring)
         return(inspect.isfunction(testfunc))
-    except:
+    except Exception:
         return (False)
 
 
@@ -24,7 +24,9 @@ def get_func(funcname, modname=None):
     return(eval(funcstring))
 
 
-def input_vars(func, inputs):
+def input_vars(func, ins):
+    from copy import deepcopy as dc
+    inputs = dc(ins)
     try:
         if hasattr(inputs, "__len__"):
             func(*inputs)
@@ -35,7 +37,9 @@ def input_vars(func, inputs):
         return (False)
 
 
-def returns(func, inputs):
+def returns(func, ins):
+    from copy import deepcopy as dc
+    inputs = dc(ins)
     try:
         if hasattr(inputs, "__len__"):
             res = func(*inputs)
@@ -44,19 +48,21 @@ def returns(func, inputs):
         if hasattr(res, "__len__"):
             res = list(res)
         return (res is not None)
-    except:
+    except Exception:
         return False
 
 
-def check_outputs(func, inputs, expected):
+def check_outputs(func, ins, expected):
     from AutoFeedback.varchecks import check_value
+    from copy import deepcopy as dc
+    inputs = dc(ins)
     try:
         res = func(*inputs)
         if hasattr(expected, "check_value") and callable(expected.check_value):
             return expected.check_value(res)
         else:
             return (check_value(res, expected))
-    except:
+    except Exception:
         return False
 
 
@@ -66,14 +72,17 @@ def check_calls(func, inputs, call):
     try:
         all_names = [c.func for c in ast.walk(
             ast.parse(inspect.getsource(func))) if isinstance(c, ast.Call)]
-        call_names = [name.id for name in all_names if isinstance(name, ast.Name)]
+        call_names = [name.id for name in all_names if
+                      isinstance(name, ast.Name)]
         return (call in call_names)
-    except:
+    except Exception:
         return False
 
 
-def check_func(funcname, inputs, expected, calls=[], modname=None, output=True):
+def check_func(funcname, inputs, expected, calls=[],
+               modname=None, output=True):
     from AutoFeedback.function_error_messages import print_error_message
+    from copy import deepcopy as copy
     call = []
     ins = inputs[0]
     outs = expected[0]
@@ -85,7 +94,7 @@ def check_func(funcname, inputs, expected, calls=[], modname=None, output=True):
 
         assert(returns(func, inputs[0])), "return"
         for ins, outs in zip(inputs, expected):
-            res = func(*ins)
+            res = func(*copy(ins))  # ensure the inputs are not overwritten
             assert(check_outputs(func, ins, outs)), "outputs"
         for call in calls:
             assert(check_calls(func, inputs[0], call)), "calls"
@@ -96,7 +105,7 @@ def check_func(funcname, inputs, expected, calls=[], modname=None, output=True):
             print_error_message(error, funcname, inp=ins,
                                 exp=outs, result=res, callname=call)
         return(False)
-    except:
+    except Exception:
         if output:
             print_error_message("execution", funcname, inp=ins)
         return(False)
