@@ -9,9 +9,9 @@ def exists(varname, modname=None):
 
     varstring = "mod."+varname  # get variable from main code
     try:
-        var = eval(varstring)
+        eval(varstring)
         return(True)
-    except:
+    except AttributeError:
         return(False)
 
 
@@ -37,6 +37,14 @@ def check_size(a, b):
 
 def check_value(a, b):
     import numpy as np
+
+    # if check_value is invoked without first having called check_size,
+    # incommensurate sizes can be missed
+    try:
+        if not check_size(a, b):
+            return False
+    except Exception:
+        return False
     try:
         import sympy as sp
         sym_installed = True
@@ -46,25 +54,26 @@ def check_value(a, b):
     if (isinstance(a, str) and isinstance(b, str)) \
             or (isinstance(a, dict) and isinstance(b, dict)):
         return (a == b)
-    elif (sym_installed and isinstance(a, sp.Basic) and isinstance(b, sp.Basic)):
+    elif (sym_installed and isinstance(a, sp.Basic) and
+          isinstance(b, sp.Basic)):
         try:
             sp.simplify(a)
             sp.simplify(b)
             return(sp.simplify(a) == sp.simplify(b) or
                    (sp.factor(a) == sp.factor(b)))
-        except:
+        except Exception:
             return(a == b)
     else:
         try:  # treat inputs as ndarrays and compare with builtin
-            return np.all(np.isclose(a, b))
+            return np.all(np.isclose(a, b)) 
         # if not ndarrays, treat as list (of strings) and compare elements
-        except:
+        except Exception:
             try:
                 for x, y in zip(a, b):
                     if not(x == y):
                         return False
                 return True
-            except:
+            except Exception:
                 return False
 
 
